/*
Copyright 2020 The Flux authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package v1beta1

import (
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
)

const (
	// GitRepositoryIndexKey is the key used for indexing resources
	// resources based on their GitRepository source.
	GitRepositoryIndexKey string = ".metadata.gitRepository"
	// HelmRepositoryIndexKey is the key used for indexing resources
	// resources based on their HelmRepository source.
	HelmRepositoryIndexKey string = ".meta.helmRepository"
	// BucketIndexKey is the key used for indexing resources based on
	// their Bucket source.
	BucketIndexKey string = ".meta.bucket"
)

// Source interface must be supported by all API types.
// +k8s:deepcopy-gen=false
type Source interface {
	// GetArtifact returns the latest artifact from the source if present in the
	// status sub-resource.
	GetArtifact() *Artifact
	// GetInterval returns the interval at which the source is updated.
	GetInterval() metav1.Duration
}
